@@ -1,10 +1,10 @@
 # @package      hubzero-submit-server
 # @file         BoundConnection.py
 # @author       Steven Clark <clarks@purdue.edu>
-# @copyright    Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# @copyright    Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 # @license      http://www.gnu.org/licenses/lgpl-3.0.html LGPLv3
 #
-# Copyright (c) 2012-2013 HUBzero Foundation, LLC.
+# Copyright (c) 2012-2014 HUBzero Foundation, LLC.
 #
 # This file is part of: The HUBzero(R) Platform for Scientific Collaboration
 #
@@ -28,8 +28,9 @@
 import os.path
 import copy
 import time
+import logging
 
-from hubzero.submit.LogMessage  import logID as log
+from hubzero.submit.LogMessage  import getLogIDMessage as getLogMessage
 from hubzero.submit.MessageCore import MessageCore
 
 class BoundConnection:
@@ -38,6 +39,7 @@ class BoundConnection:
                 submitSSLcert="",
                 submitSSLkey="",
                 submitSSLCA=""):
+      self.logger                = logging.getLogger(__name__)
       self.listeners             = {}
       self.boundSockets          = []
       self.remoteIP              = None
@@ -53,7 +55,8 @@ class BoundConnection:
          protocol,bindHost,bindPort,bindFile = self.__parseURI(listenURI)
          if   protocol == 'tls':
             if bindPort > 0:
-               log("Listening: protocol='%s', host='%s', port=%d" % (protocol,bindHost,bindPort))
+               self.logger.log(logging.INFO,getLogMessage("Listening: protocol='%s', host='%s', port=%d" % \
+                                                                        (protocol,bindHost,bindPort)))
                listener = MessageCore(protocol='tls',
                                       bindHost=bindHost,bindPort=bindPort,bindLabel=listenURI,
                                       sslKeyPath=submitSSLkey,sslCertPath=submitSSLcert,
@@ -61,19 +64,20 @@ class BoundConnection:
                                       reuseAddress=True,blocking=False)
          elif protocol == 'tcp':
             if bindPort > 0:
-               log("Listening: protocol='%s', host='%s', port=%d" % (protocol,bindHost,bindPort))
+               self.logger.log(logging.INFO,getLogMessage("Listening: protocol='%s', host='%s', port=%d" % \
+                                                                        (protocol,bindHost,bindPort)))
                listener = MessageCore(protocol='tcp',
                                       bindHost=bindHost,bindPort=bindPort,bindLabel=listenURI,
                                       reuseAddress=True,blocking=False)
          elif protocol == 'file':
             if bindFile:
-               log("Listening: '%s'" % (bindFile))
+               self.logger.log(logging.INFO,getLogMessage("Listening: '%s'" % (bindFile)))
                listener = MessageCore(protocol='file',
                                       bindFile=bindFile,
                                       bindLabel="UD:%s" % (bindFile))
          else:
             listener = None
-            log("Unknown protocol: %s" % (protocol))
+            self.logger.log(logging.ERROR,getLogMessage("Unknown protocol: %s" % (protocol)))
 
          if listener:
             if listener.isBound():
@@ -81,10 +85,10 @@ class BoundConnection:
                self.listeners[boundSocket] = listener
                self.boundSockets.append(boundSocket)
          else:
-            log("Could not bind connection to: %s" % (listenURI))
+            self.logger.log(logging.ERROR,getLogMessage("Could not bind connection to: %s" % (listenURI)))
 
       if len(self.listeners) == 0:
-         log("No listening devices configured")
+         self.logger.log(logging.ERROR,getLogMessage("No listening devices configured"))
 
 
    def __parseURI(self,
@@ -106,7 +110,7 @@ class BoundConnection:
             filePath = filePath.replace('/','',2)
       except:
          protocol = ""
-         log("Improper network specification: %s" % (uri))
+         self.logger.log(logging.ERROR,getLogMessage("Improper network specification: %s" % (uri)))
 
       return(protocol,host,port,filePath)
 
@@ -127,9 +131,9 @@ class BoundConnection:
             if reply == message:
                valid = True
       except Exception, err:
-         log("ERROR: Connection handshake failed.  Protocol mismatch?")
-         log("handshake(%s): %s" % (message.strip(),reply.strip()))
-         log("err = %s" % (str(err)))
+         self.logger.log(logging.ERROR,getLogMessage("ERROR: Connection handshake failed.  Protocol mismatch?"))
+         self.logger.log(logging.ERROR,getLogMessage("handshake(%s): %s" % (message.strip(),reply.strip())))
+         self.logger.log(logging.ERROR,getLogMessage("err = %s" % (str(err))))
 
       return(valid)
 
@@ -241,8 +245,10 @@ class BoundConnection:
 
    def sendMessage(self):
       transmittedLength = self.listeners[self.activeSocket].sendMessage(self.activeChannel,self.toBuffer)
-      if transmittedLength > 0:
+      if   transmittedLength > 0:
          self.toBuffer = self.toBuffer[transmittedLength:]
+      elif transmittedLength < 0:
+         self.closeConnection()
 
 
    def receiveMessage(self):
@@ -314,6 +320,6 @@ class BoundConnection:
    def logPendingMessage(self,
                          logMessage):
       if self.isMessagePending():
-         log("logPendingMessage(%s): %s" % (logMessage,self.toBuffer))
+         self.logger.log(logging.INFO,getLogMessage("logPendingMessage(%s): %s" % (logMessage,self.toBuffer)))
 
 
